package com.ruoyi.syzy.mapper;

import java.util.List;
import java.util.Map;

import com.ruoyi.syzy.domain.BBusiWishUniversities;
import org.apache.ibatis.annotations.Param;
import org.springframework.security.core.parameters.P;

/**
 * 院校库Mapper接口
 *
 * @author mingxue
 * @date 2021-07-29
 */
public interface BBusiWishUniversitiesMapper {

    public List<BBusiWishUniversities> selectUniversityListForTeacher(@Param("teacherId") Long teacherId, @Param("batchId") Long batchId, @Param("examType") String examType);


    public List<BBusiWishUniversities> listMyByPage(String customerCode);

    public List<Long> listForCourses(@Param("qw") String where);

    /**
     * 查询院校库
     *
     * @param id 院校库ID
     * @return 院校库
     */
    public BBusiWishUniversities selectBBusiWishUniversitiesById(Long id);
    public BBusiWishUniversities selectBBusiWishUniversitiesByCode(String code);

    /**
     * 查询院校库列表
     *
     * @param bBusiWishUniversities 院校库
     * @return 院校库集合
     */
    public List<BBusiWishUniversities> selectBBusiWishUniversitiesList(BBusiWishUniversities bBusiWishUniversities);
    public List<BBusiWishUniversities> selectBBusiWishUniversitiesListSimpleByIds(Map cond);
    public List<BBusiWishUniversities> selectBBusiWishUniversitiesListSimpleByMap(Map cond);
    public List<BBusiWishUniversities> selectMajorWishUniversitiesListSimpleByMap(Map cond);
    public List<BBusiWishUniversities> selectMajorWishUniversitiesListSimpleByMap2(Map cond);
    public List<BBusiWishUniversities> selectBBusiWishUniversitiesListSimple(BBusiWishUniversities bBusiWishUniversities);
    public List<BBusiWishUniversities> selectBBusiWishUniversitiesLocations(String entranceType);
    public List<BBusiWishUniversities> selectBBusiWishUniversitiesLocations2(String entranceType);
    public List<BBusiWishUniversities> selectBBusiWishUniversitiesLocations3(String location);
    public List<BBusiWishUniversities> selectBBusiWishUniversitiesTypes(String entranceType);
    public List<BBusiWishUniversities> selectBBusiWishUniversitiesNatureTypes(String entranceType);
    public List<BBusiWishUniversities> selectBBusiWishUniversitiesFeatures(String entranceType);
    public List<BBusiWishUniversities> selectBBusiWishUniversitiesBxTypes(String entranceType);
    public List<BBusiWishUniversities> selectBBusiWishUniversitiesLevels(String entranceType);

    /**
     * 新增院校库
     *
     * @param bBusiWishUniversities 院校库
     * @return 结果
     */
    public int insertBBusiWishUniversities(BBusiWishUniversities bBusiWishUniversities);

    /**
     * 修改院校库
     *
     * @param bBusiWishUniversities 院校库
     * @return 结果
     */
    public int updateBBusiWishUniversities(BBusiWishUniversities bBusiWishUniversities);
    public int updateCollect(@Param("id") Long id, @Param("collect") Integer collect);
    /**
     * 删除院校库
     *
     * @param id 院校库ID
     * @return 结果
     */
    public int deleteBBusiWishUniversitiesById(Long id);

    /**
     * 批量删除院校库
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteBBusiWishUniversitiesByIds(Long[] ids);

    /**
     * @param majorId
     * @return
     */
    public List<BBusiWishUniversities> listByMajorId(Long majorId);
}
